==> testdisk_6.5.orig.tar.gz: testdisk-6.5.orig/src/intrface.h <==
/*

    File: intrface.h

    Copyright (C) 1998-2006 Christophe GRENIER <grenier@cgsecurity.org>
  
    This software is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.
  
    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.
  
    You should have received a copy of the GNU General Public License along
    with this program; if not, write the Free Software Foundation, Inc., 51
    Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.

 */

#define ANALYSE_X	0
#define ANALYSE_Y	5
#define INTER_STRUCTURE	13
#define INTER_BAD_PART	10

int do_curses_testdisk(int debug, int dump_ind, const t_list_disk *list_disk, const int saveheader, const char *cmd_device, char **current_cmd);
int interface_write(t_param_disk *disk_car,t_list_part *list_part,const int can_search_deeper, const int can_ask_minmax_ext, char **current_cmd, int *menu);

t_list_part *ask_structure(t_param_disk *disk_car,t_list_part *list_part, const int debug, char **current_cmd);
void interface_analyse(t_param_disk *disk_car, const int debug, const int saveheader, char **current_cmd);
void interface_list(t_param_disk *disk_car, const int debug,const int test_recovery, const int saveheader, const int backup);
int interface_superblock(t_param_disk *disk_car,t_list_part *list_part,char**current_cmd);

==> testdisk_6.6.orig.tar.gz: testdisk-6.6.orig/src/intrface.h <==
/*

    File: intrface.h

    Copyright (C) 1998-2006 Christophe GRENIER <grenier@cgsecurity.org>
  
    This software is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.
  
    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.
  
    You should have received a copy of the GNU General Public License along
    with this program; if not, write the Free Software Foundation, Inc., 51
    Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.

 */

#define ANALYSE_X	0
#define ANALYSE_Y	5
#define INTER_STRUCTURE	13
#define INTER_BAD_PART	10

int do_curses_testdisk(int debug, int dump_ind, const t_list_disk *list_disk, const int saveheader, const char *cmd_device, char **current_cmd);
int interface_write(t_param_disk *disk_car,t_list_part *list_part,const int can_search_deeper, const int can_ask_minmax_ext, char **current_cmd, unsigned int *menu);

t_list_part *ask_structure(t_param_disk *disk_car,t_list_part *list_part, const int debug, char **current_cmd);
void interface_list(t_param_disk *disk_car, const int debug,const int test_recovery, const int saveheader, const int backup);
int interface_superblock(t_param_disk *disk_car,t_list_part *list_part,char**current_cmd);
